@@ -3,7 +3,7 @@ from datetime import datetime
 
 def info(*args):
     pref = datetime.now().strftime('[%H:%M:%S]')
-    print(pref, *args, file=sys.stdout)
+    print(pref, *args, file=sys.stdout, flush=True)
 
 def create_readme(argv, outdir):
     readmepath = os.path.join(outdir, 'README.txt')
