@@ -25,14 +25,17 @@ def pca(data, normalize=False):
     return a, evecs, evals
 
 ##########################################################
-def get_pc_contribution(evecs):
+def get_pc_contribution(evecs, evals):
     """Get the id and calculate the relative contribution of the feature
     with major contribution to the first two components. Notice that the
     values are relative to each component and thus the sum may surpass 1."""
-    pcs = []; contribs = []
-    for i in range(2): # Just two major components
+    n = 2
+    pcs = []; relcontribs = []
+    contribs = (evals / np.max(evals))[:n]
+
+    for i in range(n): # Just two major components
         evec = np.abs(evecs[:, i])
-        contrib = evec / np.sum(evec)
-        pcs.append(np.argsort(contrib)[-1])
-        contribs.append(np.max(contrib))
-    return contribs
+        relcontrib = evec / np.sum(evec)
+        pcs.append(np.argsort(relcontrib)[-1])
+        relcontribs.append(np.max(relcontrib))
+    return pcs, contribs, relcontribs
